@@ -8,14 +8,16 @@ from .edn_dump import dump as dumps
 from .exceptions import EDNDecodeError
 from .immutable_dict import ImmutableDict
 from .immutable_list import ImmutableList
+from .char import Char
 
 __all__ = (
     'ImmutableList',
-    'EDNDecodeError',
     'ImmutableDict',
     'Keyword',
     'Symbol',
+    'Char',
     'TaggedElement',
+    'EDNDecodeError',
     'add_tag',
     'dumps',
     'loads',
