@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
-class Char(str):
+from .compat import unicode
+
+
+class Char(unicode):
     """
     This class represents a one-character string.
     """
