@@ -2,7 +2,6 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 import datetime
-import sys
 import uuid
 from collections import deque
 
@@ -14,11 +13,7 @@ from .exceptions import EDNDecodeError
 from .immutable_dict import ImmutableDict
 from .immutable_list import ImmutableList
 
-
-if sys.version_info[0] == 3:
-    long = int
-    basestring = str
-    unicode = str
+from .compat import basestring, unicode
 
 # Dummy statement to indicate that 'tokens' is used.
 if tokens:
